import * as React from "react";
import Stack from "@mui/material/Stack";
import NotificationsRoundedIcon from "@mui/icons-material/NotificationsRounded";
import CustomDatePicker from "../CustomDatePicker";
import NavbarBreadcrumbs from "../NavbarBreadcrumbs";
import MenuButton from "../MenuButton";
import ColorModeIconDropdown from "../../shared-theme/ColorModeIconDropdown";
import Box from "@mui/material/Box";
import Typography from "@mui/material/Typography";
import Search from "../Search";

export default function Header() {
	const [showNotifications, setShowNotifications] = React.useState(false);
	const toggleNotifications = () => {
		setShowNotifications((prev) => !prev);
	};
	return (
		<Stack
			direction="row"
			sx={{
				display: { xs: "none", md: "flex" },
				width: "100%",
				alignItems: { xs: "flex-start", md: "center" },
				justifyContent: "space-between",
				maxWidth: { sm: "100%", md: "1700px" },
				pt: 1.5,
			}}
			spacing={2}
		>
			<NavbarBreadcrumbs />
			<Stack direction="row" sx={{ gap: 1 }}>
				<Search />
				<CustomDatePicker />
				<MenuButton
					showBadge
					aria-label="Open notifications"
					onClick={toggleNotifications}
				>
					<NotificationsRoundedIcon />
				</MenuButton>
				<ColorModeIconDropdown />
			</Stack>
			{showNotifications && (
				<Box
					sx={{
						p: 2,
						position: "absolute",
					    top: "55px", // Adjust this value according to your AppBar height
						right: "66px",
						bgcolor: "lightblue",
						boxShadow: 1,
						borderRadius: 1,
						zIndex: 1300,
					}}
				>
					<Typography variant="body2" color="text.secondary">
						No notifications yet
					</Typography>
				</Box>
			)}
		</Stack>
	);
}
