// src/pages/Dashboard

import * as React from 'react';
import { Box, CssBaseline, Typography } from '@mui/material';

import {
  chartsCustomizations,
  dataGridCustomizations,
  datePickersCustomizations,
  treeViewCustomizations,
} from './theme/customizations';
import DashboardLayout from '../../layouts/DashboardLayout';
import AppTheme from '../../shared-theme/AppTheme';
import MainGrid from '../../components/MainGrid';

const xThemeComponents = {
  ...chartsCustomizations,
  ...dataGridCustomizations,
  ...datePickersCustomizations,
  ...treeViewCustomizations,
};

interface DashboardProps {
  disableCustomTheme?: boolean;
}

const Dashboard: React.FC<DashboardProps> = ({ disableCustomTheme = false }) => {
  return (
    <AppTheme {...{ disableCustomTheme }} themeComponents={xThemeComponents}>
      <CssBaseline enableColorScheme />
      {!disableCustomTheme ? (
        <MainGrid />
      ) : (
        <Box
          sx={{
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center',
            height: '100vh',
            textAlign: 'center',
            padding: 2,
          }}
        >
          <Box>
            <Typography variant="h6" component="h1" gutterBottom>
              Dashboard
            </Typography>
            <Typography variant="body1" sx={{ marginTop: 2 }}>
              No content available on the Dashboard yet.
            </Typography>
          </Box>
        </Box>
      )}
    </AppTheme>
  );
};

export default Dashboard;
